<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

include("auth.php");
?>
<html>
<head>
<title>Parallels Confixx</title>
</head>
<script>
top.fraTitle.location.href = 'title_se.php';
top.fraHelp.location.href = 'bottom.php';
top.fraLeft.location.href = 'left.php';
top.fraRight.location.href = 'right.php';
</script>
  <frameset cols ="230,*" border=0 frameborder=0 framespacing=0>
    <frame name=menu             src="menu_se.php?num=1" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
    <frame name=content    src="se_start.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
  </frameset>
</html>
